@@ -22,7 +22,6 @@
 #include <QJsonObject>
 #include <QJsonArray>
 #include <QApplication>
-#include <QStandardPaths>
 
 
 #undef signals
@@ -451,16 +450,12 @@ QStringList MimesAppsManager::getRecommendedAppsByGio(const QString &mimeType)
 QStringList MimesAppsManager::getApplicationsFolders()
 {
     QStringList desktopFolders;
-    desktopFolders << QString("/usr/share/applications")
-                   << QString("/usr/local/share/applications")
-                   << QString("/usr/share/gnome/applications");
-    // env for XDG_DATA_DIRS
-    for (const QString &path : QStandardPaths::standardLocations(QStandardPaths::ApplicationsLocation)) {
-      if (desktopFolders.contains(path))
-          continue;
-      desktopFolders.append(path);
-    }
-
+    desktopFolders << QString("/usr/share/applications/")
+                   << QString("/usr/local/share/applications/")
+                   << QString("/usr/share/gnome/applications/")
+                   << QString("/var/lib/flatpak/exports/share/applications")
+                   << QDir::homePath() + QString("/.local/share/flatpak/exports/share/applications")
+                   << QDir::homePath() + QString("/.local/share/applications");
     return desktopFolders;
 }
 
@@ -577,7 +572,7 @@ void MimesAppsManager::initMimeTypeApps()
                 orderApps.append(info.absoluteFilePath());
             }
         } else {
-            orderApps.append(apps.toList());
+            orderApps.append(apps.values());
         }
 
         MimeApps.insert(key, orderApps);
@@ -706,7 +701,11 @@ void MimesAppsManager::loadDDEMimeTypes()
 
 bool MimesAppsManager::lessByDateTime(const QFileInfo &f1, const QFileInfo &f2)
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     return f1.created() < f2.created();
+#else
+    return f1.birthTime() < f2.birthTime();
+#endif
 }
 
 bool MimesAppsManager::removeOneDupFromList(QStringList &list, const QString desktopFilePath)
