@@ -14,7 +14,8 @@
 #include <DApplication>
 #include <DFileDialog>
 #include <DFontSizeManager>
-#include <DApplicationHelper>
+#include <DGuiApplicationHelper>
+#include <DPaletteHelper>
 
 #include <QStandardPaths>
 #include <QFocusEvent>
@@ -27,6 +28,11 @@
 #include <QDebug>
 
 #include <cmath>
+#include <QProcess>
+#ifdef DTKCORE_CLASS_DConfigFile
+#include <DConfig>
+DCORE_USE_NAMESPACE
+#endif
 
 #define SCROLL_MAX 621
 #define SCROLL_MIN 348
@@ -82,6 +88,7 @@ void TypeLabel::focusOutEvent(QFocusEvent *event)
 CompressSettingPage::CompressSettingPage(QWidget *parent)
     : DWidget(parent)
 {
+    initConfig();
     initUI();
     initConnections();
     slotAdvancedEnabled(m_pAdvancedBtn->isChecked());
@@ -141,17 +148,11 @@ void CompressSettingPage::refreshMenu()
     QAction *pAction = nullptr;
     bool bHas7z = false;
     for (const QString &type : qAsConst(m_listSupportedMimeTypes)) {
-        QMimeType mType = QMimeDatabase().mimeTypeForName(type);
-        // QStringList suffixLst = mType.globPatterns(); 支持的后缀名
-        QString suffix = mType.preferredSuffix();
-        if(type.contains("x-7z-compressed")) {
-            suffix = "7z";
-        }
-        if (suffix == "7z") {
+        if (QMimeDatabase().mimeTypeForName(type).preferredSuffix() == "7z") {
             bHas7z = true;
         }
 
-        pAction = new QAction(suffix, m_pTypeMenu);
+        pAction = new QAction(QMimeDatabase().mimeTypeForName(type).preferredSuffix(), m_pTypeMenu);
         pAction->setData(type);
         m_pTypeMenu->addAction(pAction);
 
@@ -166,6 +167,21 @@ void CompressSettingPage::refreshMenu()
             m_pTypeMenu->addAction("tar.7z");
         }
     }
+#ifdef DTKCORE_CLASS_DConfigFile
+    if(m_isOrderMode) {
+        DConfig *dconfig = (DConfig *)m_dconfig;
+        int nCompType = -1;
+        if(dconfig && dconfig->isValid() && dconfig->keyList().contains("specialCompressorType")){
+                    nCompType = dconfig->value("specialCompressorType").toInt();
+                }
+        QList<QAction*> lstAct = m_pTypeMenu->actions();
+        if(nCompType >= 0 && nCompType < lstAct.count()) {
+            slotTypeChanged(lstAct.at(nCompType));
+            return;
+        }
+    }
+#endif
+
 
     // 默认选择类型为zip
     if (pAction != nullptr) {
@@ -181,15 +197,19 @@ void CompressSettingPage::initUI()
     m_pCompressTypeLbl = new DLabel(this);
     pArrowPixmapLbl = new DLabel(this);
 
-    m_pClickLbl->setMinimumSize(125, 40);
+    m_pClickLbl->setMinimumWidth(125);
     m_pClickLbl->setObjectName("ClickTypeLabel");
     m_pClickLbl->setFocusPolicy(Qt::TabFocus);
     m_pClickLbl->installEventFilter(this);
 
     DStyle style;   // 设置菜单箭头
     QPixmap pixmap = style.standardIcon(DStyle::StandardPixmap::SP_ReduceElement).pixmap(QSize(10, 10));
-    pArrowPixmapLbl->setMinimumHeight(25);
     pArrowPixmapLbl->setPixmap(pixmap);
+    connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, [=]() {
+        DStyle style;   // 设置菜单箭头
+        QPixmap pixmap = style.standardIcon(DStyle::StandardPixmap::SP_ReduceElement).pixmap(QSize(10, 10));
+        pArrowPixmapLbl->setPixmap(pixmap);
+    });
 
     DFontSizeManager::instance()->bind(m_pCompressTypeLbl, DFontSizeManager::T5, QFont::DemiBold);
 
@@ -213,20 +233,20 @@ void CompressSettingPage::initUI()
     m_pCommentEdt = new DTextEdit(this);
     m_pCompressBtn = new CustomPushButton(tr("Compress", "button"), this);
 
-    m_pFileNameEdt->setMinimumSize(260, 36);    // 配置文件名属性
+    m_pFileNameEdt->setMinimumWidth(260);    // 配置文件名属性
     QLineEdit *pNameEdt = m_pFileNameEdt->lineEdit();
     pNameEdt->setMaxLength(70);
     m_pFileNameEdt->setText(tr("New Archive"));
 
     m_pSavePathEdt->setFileMode(DFileDialog::Directory);        // 配置保存路径
     m_pSavePathEdt->setText(QStandardPaths::writableLocation(QStandardPaths::DesktopLocation));
-    m_pSavePathEdt->setMinimumSize(260, 36);
+    m_pSavePathEdt->setMinimumWidth(260);
 
-    m_pCompressLevelCmb->setMinimumSize(260, 36);   // 设置压缩方式尺寸
+    m_pCompressLevelCmb->setMinimumWidth(260);   // 设置压缩方式尺寸
     m_pCompressLevelCmb->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed); // 跟随界面缩放
 
 
-    m_pCpuCmb->setMinimumSize(260, 36);   // 设置压缩方式尺寸
+    m_pCpuCmb->setMinimumWidth(260);   // 设置压缩方式尺寸
     m_pCpuCmb->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed); // 跟随界面缩放
 
     // 设置压缩方式选项
@@ -254,7 +274,7 @@ void CompressSettingPage::initUI()
     m_pListEncryptionLbl->setEnabled(false);
 
     // 待确认
-    m_pSplitValueEdt->setMinimumSize(260, 36);
+    m_pSplitValueEdt->setMinimumWidth(260);
     m_pSplitValueEdt->setSuffix("MB");
     m_pSplitValueEdt->setRange(0.0, 1000000);
     m_pSplitValueEdt->setSingleStep(0.1);
@@ -265,7 +285,7 @@ void CompressSettingPage::initUI()
     m_pCommentEdt->setPlaceholderText(tr("Enter up to %1 characters").arg(MAXCOMMENTLEN));
     m_pCommentEdt->setTabChangesFocus(true); // DTextEdit中Tab键切换焦点
 
-    m_pCompressBtn->setMinimumSize(340, 36);    // 设置压缩按钮最小尺寸
+    m_pCompressBtn->setMinimumWidth(340);    // 设置压缩按钮最小尺寸
 
     // 左侧布局
     QHBoxLayout *pTypeLayout = new QHBoxLayout; // 类型布局
@@ -295,8 +315,10 @@ void CompressSettingPage::initUI()
 
     // 右侧内容布局
     QVBoxLayout *pRightLayout = new QVBoxLayout;
+    pRightLayout->setSpacing(5);
     pRightLayout->addWidget(pLabName);
     pRightLayout->addWidget(m_pFileNameEdt);
+    pRightLayout->addSpacing(7);
     pRightLayout->addWidget(pLabSave);
     pRightLayout->addWidget(m_pSavePathEdt);
     pRightLayout->addWidget(m_pCompressLevelLbl);
@@ -366,7 +388,7 @@ void CompressSettingPage::initConnections()
     connect(m_pPasswordEdt, &DPasswordEdit::echoModeChanged, this, &CompressSettingPage::slotEchoModeChanged);
     connect(m_pPasswordEdt, &DPasswordEdit::textEdited, this, &CompressSettingPage::slotPasswordChanged);
     connect(m_pCommentEdt, &DTextEdit::textChanged, this, &CompressSettingPage::slotCommentTextChanged);
-    connect(DApplicationHelper::instance(), &DApplicationHelper::themeTypeChanged, this, &CompressSettingPage::slotRefreshFileNameEdit);
+    connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &CompressSettingPage::slotRefreshFileNameEdit);
 }
 
 void CompressSettingPage::setTypeImage(const QString &strType)
@@ -444,6 +466,90 @@ void CompressSettingPage::setSplitEnabled(bool bEnabled)
 
 void CompressSettingPage::refreshCompressLevel(const QString &strType)
 {
+#ifdef DTKCORE_CLASS_DConfigFile
+    if(m_isOrderMode) {
+        // 其余格式支持设置压缩方式
+        // 设置压缩方式可用
+        m_pCompressLevelCmb->setEnabled(true);
+        m_pCompressLevelLbl->setEnabled(true);
+        if(!m_dconfig) return;
+        DConfig *dconfig = (DConfig *)m_dconfig;
+        if(strType == "7z") {
+            if(dconfig && dconfig->isValid() && dconfig->keyList().contains("special7zCompressor")){
+                        int nMethod = dconfig->value("special7zCompressor").toInt();
+                        m_pCompressLevelCmb->setCurrentIndex(nMethod);
+                    }
+        } else if(strType == "jar") {
+            if(dconfig && dconfig->isValid() && dconfig->keyList().contains("specialJarCompressor")){
+                        int nMethod = dconfig->value("specialJarCompressor").toInt();
+                        m_pCompressLevelCmb->setCurrentIndex(nMethod);
+                    }
+        } else if(strType == "tar") {
+            // tar只有存储功能
+            m_pCompressLevelCmb->setCurrentIndex(0);
+            // 设置压缩方式不可用
+            m_pCompressLevelCmb->setEnabled(false);
+            m_pCompressLevelLbl->setEnabled(false);
+        } else if(strType == "tar.bz2") {
+            if(dconfig && dconfig->isValid() && dconfig->keyList().contains("specialTarbz2Compressor")){
+                        int nMethod = dconfig->value("specialTarbz2Compressor").toInt();
+                        m_pCompressLevelCmb->setCurrentIndex(nMethod);
+                    }
+        } else if(strType == "tar.gz") {
+            if(dconfig && dconfig->isValid() && dconfig->keyList().contains("specialTarGzCompressor")){
+                        int nMethod = dconfig->value("specialTarGzCompressor").toInt();
+                        m_pCompressLevelCmb->setCurrentIndex(nMethod);
+                    }
+            if(dconfig && dconfig->isValid() && dconfig->keyList().contains("specialCpuTarGzCompressor")){
+                        int nCpu = dconfig->value("specialCpuTarGzCompressor").toInt();
+                        m_pCpuCmb->setCurrentIndex(nCpu);
+                    }
+        } else if(strType == "tar.gz") {
+             if(dconfig && dconfig->isValid() && dconfig->keyList().contains("specialTarGzCompressor")){
+                       int nMethod = dconfig->value("specialTarGzCompressor").toInt();
+                       m_pCompressLevelCmb->setCurrentIndex(nMethod);
+                    }
+        } else if(strType == "tar.lz") {
+            if(dconfig && dconfig->isValid() && dconfig->keyList().contains("specialTarLzCompressor")){
+                      int nMethod = dconfig->value("specialTarLzCompressor").toInt();
+                      m_pCompressLevelCmb->setCurrentIndex(nMethod);
+                   }
+       } else if(strType == "tar.lzma") {
+            if(dconfig && dconfig->isValid() && dconfig->keyList().contains("specialTarLzmaCompressor")){
+                      int nMethod = dconfig->value("specialTarLzmaCompressor").toInt();
+                      m_pCompressLevelCmb->setCurrentIndex(nMethod);
+                   }
+       } else if(strType == "tar.lzo") {
+            if(dconfig && dconfig->isValid() && dconfig->keyList().contains("specialTarLzoCompressor")){
+                      int nMethod = dconfig->value("specialTarLzoCompressor").toInt();
+                      m_pCompressLevelCmb->setCurrentIndex(nMethod);
+                   }
+       } else if(strType == "tar.xz") {
+            if(dconfig && dconfig->isValid() && dconfig->keyList().contains("specialTarXzCompressor")){
+                      int nMethod = dconfig->value("specialTarXzCompressor").toInt();
+                      m_pCompressLevelCmb->setCurrentIndex(nMethod);
+                   }
+       } else if(strType == "tar.Z") {
+            // tar.Z无压缩方式，使用默认，即标准
+            m_pCompressLevelCmb->setCurrentIndex(3);
+            // 设置压缩方式不可用
+            m_pCompressLevelCmb->setEnabled(false);
+            m_pCompressLevelLbl->setEnabled(false);
+       } else if(strType == "tar.7z") {
+            if(dconfig && dconfig->isValid() && dconfig->keyList().contains("specialTar7zCompressor")){
+                      int nMethod = dconfig->value("specialTar7zCompressor").toInt();
+                      m_pCompressLevelCmb->setCurrentIndex(nMethod);
+                   }
+       } else if(strType == "zip") {
+            if(dconfig && dconfig->isValid() && dconfig->keyList().contains("specialZipCompressor")){
+                      int nMethod = dconfig->value("specialZipCompressor").toInt();
+                      m_pCompressLevelCmb->setCurrentIndex(nMethod);
+                   }
+       }
+       return;
+   }
+#endif
+
     if (0 == strType.compare("tar")) {
         // tar只有存储功能
         m_pCompressLevelCmb->setCurrentIndex(0);
@@ -581,6 +687,25 @@ void CompressSettingPage::setDefaultName(const QString &strName)
     qfilename->setFocus();
 }
 
+void CompressSettingPage::initConfig()
+{
+#ifdef DTKCORE_CLASS_DConfigFile
+    QProcess process;
+    process.start("dmidecode");
+    process.waitForStarted();
+    process.waitForFinished();
+    QString result = process.readAll();
+    QStringList lines = result.split('\n');
+    for (const QString &line : lines) {
+        if (line.contains("String 4", Qt::CaseInsensitive)) {
+            m_isOrderMode = line.contains("PGUX", Qt::CaseInsensitive) || line.contains("FXK11", Qt::CaseInsensitive);
+        }
+    }
+    process.close();
+    m_dconfig = DConfig::create("org.deepin.compressor","org.deepin.compressor.method");
+#endif
+}
+
 void CompressSettingPage::slotShowRightMenu(QMouseEvent *e)
 {
     Q_UNUSED(e)
@@ -602,6 +727,7 @@ void CompressSettingPage::slotTypeChanged(QAction *action)
 
     m_pCpuLbl->setEnabled(false);
     m_pCpuCmb->setEnabled(false);
+    m_pCpuCmb->setCurrentIndex(0);
 
     if (0 == selectType.compare("tar.7z")) {       // tar.7z支持普通/列表加密，不支持分卷
         setEncryptedEnabled(true);
@@ -627,6 +753,7 @@ void CompressSettingPage::slotTypeChanged(QAction *action)
         if (0 == selectType.compare("tar.gz")) {
             m_pCpuLbl->setEnabled(true);
             m_pCpuCmb->setEnabled(true);
+            m_pCpuCmb->setCurrentIndex(m_pCpuCmb->count() - 1);
         }
     }
 
@@ -635,7 +762,7 @@ void CompressSettingPage::slotTypeChanged(QAction *action)
 
 void CompressSettingPage::slotRefreshFileNameEdit()
 {
-    DPalette plt = DApplicationHelper::instance()->palette(m_pFileNameEdt);
+    DPalette plt = DPaletteHelper::instance()->palette(m_pFileNameEdt);
 
     if (!m_pFileNameEdt->text().isEmpty()) {
         // 检测文件名合法性
@@ -681,12 +808,25 @@ void CompressSettingPage::slotAdvancedEnabled(bool bEnabled)
         m_pCpuCmb->setCurrentIndex(0);
         m_pCommentEdt->clear();
     }
-
-
+    if (m_pCompressTypeLbl->text() == "tar.gz") {
+        m_pCpuCmb->setCurrentIndex(m_pCpuCmb->count() - 1);
+#ifdef DTKCORE_CLASS_DConfigFile
+        if(m_isOrderMode) {
+            DConfig *dconfig = (DConfig *)m_dconfig;
+            if(dconfig && dconfig->isValid() && dconfig->keyList().contains("specialCpuTarGzCompressor")){
+                int nCpu = dconfig->value("specialCpuTarGzCompressor").toInt();
+                m_pCpuCmb->setCurrentIndex(nCpu);
+            }
+        }
+#endif
+    }
 }
 
 void CompressSettingPage::slotSplitEdtEnabled()
 {
+    if(m_pSplitValueEdt->hasFocus() || m_pCommentEdt->hasFocus()) {
+        parentWidget()->setFocus();
+    }
     // 设置分卷输入框是否可用
     m_pSplitValueEdt->setEnabled(m_pSplitCkb->isChecked());
 
@@ -717,11 +857,13 @@ void CompressSettingPage::slotCompressClicked()
     }
 
     //压缩zip分卷不支持中文密码
-    if (m_pSplitCkb->isChecked()
-            && "zip" == m_pCompressTypeLbl->text()
-            && (!m_pPasswordEdt->text().isEmpty() && m_pPasswordEdt->text().contains(QRegExp("[\\x4e00-\\x9fa5]+")))) {
-        m_pPasswordEdt->showAlertMessage(tr("The password for ZIP volumes cannot be in Chinese"));
-        return;
+    if (m_pSplitCkb->isChecked() && "zip" == m_pCompressTypeLbl->text()) {
+        QString strPassword = m_pPasswordEdt->lineEdit()->text();
+        QRegularExpression chineseRegex("[\\x{4e00}-\\x{9fa5}]+");
+        if (!strPassword.isEmpty() && chineseRegex.match(strPassword).hasMatch()) {
+            m_pPasswordEdt->showAlertMessage(tr("The password for ZIP volumes cannot be in Chinese"));
+            return;
+        }
     }
 
     // 检查合法性
@@ -812,16 +954,17 @@ void CompressSettingPage::slotCommentTextChanged()
 
 void CompressSettingPage::slotPasswordChanged()
 {
-    QRegExp reg("^[\\x00-\\x80\\x4e00-\\x9fa5]+$");
+    QRegularExpression reg("^[\\x00-\\x80\\x{4e00}-\\x{9fa5}]+$");
     QString pwdin = m_pPasswordEdt->lineEdit()->text();
     QString pwdout;
 
-    if (!pwdin.isEmpty() && !reg.exactMatch(pwdin)) {
+    if (!pwdin.isEmpty() && !reg.match(pwdin).hasMatch()) {
         for (int i = 0; i < pwdin.length(); ++i) {
-            if (reg.exactMatch(pwdin.at(i))) {
-                pwdout.push_back(pwdin.at(i));
+            if (reg.match(pwdin.at(i)).hasMatch()) {
+                pwdout.append(pwdin.at(i));
             }
         }
+
         m_pPasswordEdt->setText(pwdout);
         // 仅支持中英文字符及部分符号
         m_pPasswordEdt->showAlertMessage(tr("Only Chinese and English characters and some symbols are supported"));
@@ -864,6 +1007,11 @@ bool CompressSettingPage::eventFilter(QObject *watched, QEvent *event)
     }
 }
 
+bool CompressSettingPage::isOrderMode()
+{
+    return m_isOrderMode;
+}
+
 TypeLabel *CompressSettingPage::getClickLbl() const
 {
     return m_pClickLbl;
