@@ -58,7 +58,7 @@ void UnCompressView::refreshArchiveData()
 
     // 重置排序
     m_pHeaderView->setSortIndicator(-1, Qt::SortOrder::AscendingOrder);
-    sortByColumn(DC_Name);
+    sortByColumn(DC_Name, Qt::AscendingOrder);
     resetLevel();       // 重置目录层级
 }
 
@@ -259,7 +259,7 @@ void UnCompressView::handleDoubleClick(const QModelIndex &index)
             resizeColumnWidth();            // 重置列宽
             // 重置排序
             m_pHeaderView->setSortIndicator(-1, Qt::SortOrder::AscendingOrder);
-            sortByColumn(DC_Name);
+            sortByColumn(DC_Name, Qt::AscendingOrder);
 
             m_vPre.push_back(entry.strFileName); // 保存进入的文件夹名
 
@@ -337,7 +337,7 @@ void UnCompressView::refreshDataByCurrentPathChanged()
 
     // 重置排序
     m_pHeaderView->setSortIndicator(-1, Qt::SortOrder::AscendingOrder);
-    sortByColumn(DC_Name);
+    sortByColumn(DC_Name, Qt::AscendingOrder);
 
     // 追加时需要选中追加的文件
     if (CT_Add == m_eChangeType) {
@@ -618,21 +618,25 @@ void UnCompressView::slotShowRightMenu(const QPoint &pos)
         if(selectionModel()->selectedRows().count() != 1 || !m_bModifiable) {
             renameAct->setEnabled(false);
         }
+        if(m_mapOrderJson.contains(ORDER_RENAME)) {
+            renameAct->setEnabled(m_mapOrderJson.value(ORDER_RENAME).toBool());
+        }
         // 右键-删除
         QAction *pAction = menu.addAction(tr("Delete"), this, &UnCompressView::slotDeleteFile);
 
         if (!m_bModifiable) {
             pAction->setEnabled(false); // 若压缩包数据不能更改，深处按钮设置成不可用
         }
-
+        if(m_mapOrderJson.contains(ORDER_DELETE)) {
+            pAction->setEnabled(m_mapOrderJson.value(ORDER_DELETE).toBool());
+        }
         // 右键-打开方式
         DMenu openMenu(tr("Open with"), this);
         menu.addMenu(&openMenu);
 
         // 右键-选择默认应用程序
         openMenu.addAction(tr("Select default program"), this, SLOT(slotOpenStyleClicked()));
-        int nMax = 0;
-        QFontMetrics fm(openMenu.font());
+
         if (m_stRightEntry.isDirectory) {
             openMenu.setEnabled(false);
         } else {
@@ -641,22 +645,11 @@ void UnCompressView::slotShowRightMenu(const QPoint &pos)
             QList<DesktopFile> listOpenType = OpenWithDialog::getOpenStyle(m_stRightEntry.strFullPath);
             // 添加菜单选项
             for (int i = 0; i < listOpenType.count(); ++i) {
-                QIcon icon = QIcon::fromTheme(listOpenType[i].getIcon());
-                QAction *pOpenAction = openMenu.addAction(icon, listOpenType[i].getDisplayName(), this, SLOT(slotOpenStyleClicked()));
-                if(!icon.isNull()) {
-                    int nWidth = fm.width(listOpenType[i].getDisplayName()) * qApp->devicePixelRatio();
-                    if(nWidth > nMax) {
-                        nMax = nWidth;
-                    }
-                }
+                QAction *pOpenAction = openMenu.addAction(QIcon::fromTheme(listOpenType[i].getIcon()), listOpenType[i].getDisplayName(), this, SLOT(slotOpenStyleClicked()));
                 pOpenAction->setData(listOpenType[i].getExec());
             }
         }
-        if(nMax > menu.minimumWidth()) {
-            openMenu.setMinimumWidth(nMax);
-        } else {
-            openMenu.setMinimumWidth(menu.minimumWidth());
-        }
+
         menu.exec(viewport()->mapToGlobal(pos));
     }
 }
@@ -690,6 +683,11 @@ void UnCompressView::slotExtract2Here()
 
 void UnCompressView::slotDeleteFile()
 {
+    QVariantMap mapdata = mapOrderJson();
+    if(mapdata.contains(ORDER_DELETE)) {
+        if(!mapdata.value(ORDER_DELETE).toBool()) return;
+    }
+
     if (m_bModifiable) { // 压缩包数据是否可更改
         // 询问删除对话框
         SimpleQueryDialog dialog(this);
@@ -819,7 +817,7 @@ void UnCompressView::slotPreClicked()
 
     // 重置排序
     m_pHeaderView->setSortIndicator(-1, Qt::SortOrder::AscendingOrder);
-    sortByColumn(DC_Name);
+    sortByColumn(DC_Name, Qt::AscendingOrder);
 
     //自动选中第一行
     QModelIndex tmpindex = m_pModel->getListEntryIndex(m_vPre.back()); // 获取上层文件夹对应的QModelIndex
